import { App } from "@vue/runtime-core";
import type { VueWrapper, MountingOptions } from "@vue/test-utils";
import { EffectScope } from "vue";
import { StoreManagerEventBus } from "./EventBus/StoreManagerEventBus";
import type { StoreMetaData } from "./Meta/StoreMetaData";
import type { TestingStoreType, StoreLoaderModule, StoreType } from "./Types";
export declare class StoreManagerInstance {
    private app;
    __scope: EffectScope;
    private didInstantiateStores;
    /**
     * Holds store Class Name -> Store Instance
     */
    stores: {
        [key: string]: StoreType;
    };
    /**
     * Holds store Class Name -> Store Module
     */
    storeModules: {
        [key: string]: any;
    };
    /**
     * Holds store Class Name -> Store Meta
     */
    storeMeta: {
        [key: string]: StoreMetaData;
    };
    /**
     * Holds a reference of Binding -> Class Name for quick lookup
     */
    storeBindingToClassName: {
        [key: string]: string;
    };
    /**
     * Holds a reference of class name -> Store instance & Store constructor
     *
     * This is only used for testing
     */
    storeInjections: {
        [key: string]: {
            store: TestingStoreType;
            meta: StoreMetaData;
            storeConstructor: new (...args: any) => TestingStoreType;
        };
    };
    bus: StoreManagerEventBus;
    private extensions;
    constructor();
    runInScope(fn: () => any): void;
    /**
     * The call to this method is transformed by the vite plugin
     * It will automatically add the store loader `import.meta.glob('', {eager:true})` call as a parameter
     *
     * The end developer just needs to use `app.use(StoreManager.boot())`
     *
     * @returns {{install: (app: App) => void}}
     */
    boot(): {
        install: (app: App) => void;
    };
    bootForTesting(): {
        install: (app: App) => void;
    };
    /**
     * Created a @vue/test-utils component instance with the store manager attached
     */
    testComponentInstance(component?: any, options?: MountingOptions<any>): Promise<VueWrapper>;
    private bootFromLoader;
    /**
     * This should only be used in tests
     *
     * It should be called before mounting your component, for example:
     *
     * ```
     *  const store = new TestStoreClass();
     * 	StoreManager.injectStore(store, TestStoreClass);
     *
     * 	const component = mount(Component, {
     * 		global : {plugins : [StoreManager.bootForTesting()]}
     * 	});
     * ```
     */
    injectStore(storeInstance: any, storeConstructor: new (...args: any) => any): void;
    /**
     * This should only be used in tests
     */
    loadStoresFromInjections(): void;
    loadStoresFromLoader(storeLoader: StoreLoaderModule): void;
    /**
     * Run the stores `pre init` stage
     * This is where it's imported, the binding/meta is setup and
     * the store is registered on our store manager.
     */
    private prepareStore;
    /**
     * Run the stores main `init` stage.
     *
     * This is where all bindings will be setup and the `init` hook will be called.
     */
    private loadStore;
    private addExtensions;
    extend(extensionFunc: () => {
        [key: string]: any;
    }): void;
    /**
     * We have to compromise... we can only handle hot reloads for
     * store meta or individual store modules.... however,
     * It seems like when we use the meta's lazy import module
     * function, it fetches the latest store version....
     * Just means we have to process all stores on hot reload :|
     */
    loaderReloaded(storesMeta: StoreMetaData[]): void;
}
declare const storeManager: StoreManagerInstance;
export default storeManager;
