import ts from "typescript";
import { LifeCycleEvent } from "../../Common/LifeCycle";
import { SignatureMetaDecoratorInfo, SignatureMetaParamInfo } from "../AstHelpers/Signature";
export declare type DecoratorMetaInfo = {
    n: string;
    p: {
        n: string;
        v: string;
    }[];
};
export declare class ActionMeta {
    /**
     * The name of the method
     */
    name: string;
    /**
     * The parameters of the method
     */
    params: SignatureMetaParamInfo[];
    /**
     * The decorators defined on the method
     */
    decorators: {
        [key: string]: SignatureMetaDecoratorInfo;
    };
    decoratorMeta: {
        [key: string]: DecoratorMetaInfo;
    };
    /**
     * If we defined a lifecycle decorator on the method, we'll return it here
     */
    lifeCycleEventHandler: LifeCycleEvent;
    /**
     * Typescript AST for the method
     */
    readonly method: ts.MethodDeclaration;
    constructor(method: ts.MethodDeclaration);
    prepare(): void;
    isValid(): boolean;
    toJSON(): {
        name: string;
        params: SignatureMetaParamInfo[];
        lifeCycleEventHandler: LifeCycleEvent;
    };
    private setDecorator;
    private defineDecorator;
    toMetaObject(): {
        n: string;
        p: {
            n: string;
            t: string;
            dv: string;
        }[];
        d: {
            [key: string]: DecoratorMetaInfo;
        };
        h: LifeCycleEvent;
    };
}
