"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.extractSignatureMeta = exports.extractDefaultValue = exports.extractDecoratorsFromSignature = void 0;
const typescript_1 = __importDefault(require("typescript"));
const TS_1 = require("../TS");
function extractDecoratorsFromSignature(method, validatorFunc) {
    var _a;
    const decorators = typescript_1.default.canHaveDecorators(method)
        ? typescript_1.default.getDecorators(method)
        : undefined;
    if (!decorators) {
        return [];
    }
    const decoratorsInfo = [];
    for (let decorator of decorators) {
        const expression = decorator.expression;
        const decoratorInfo = {
            name: undefined,
            parameters: [],
        };
        if (typescript_1.default.isCallExpression(expression)) {
            const sig = TS_1.TS.typeChecker.getResolvedSignature(expression);
            if (sig) {
                decoratorInfo.name = expression.expression.getText();
                if ((_a = sig.parameters) === null || _a === void 0 ? void 0 : _a.length) {
                    for (let i = 0; i < sig.parameters.length; i++) {
                        const parameterName = sig.parameters[i].name;
                        const parameterValue = expression.arguments[i].getText();
                        decoratorInfo.parameters[i] = {
                            name: parameterName,
                            value: parameterValue,
                        };
                    }
                }
            }
        }
        if (typescript_1.default.isIdentifier(expression)) {
            decoratorInfo.name = expression.getText();
        }
        if (decoratorInfo.name === undefined) {
            continue;
        }
        if (validatorFunc && !validatorFunc(decorator, decoratorInfo)) {
            continue;
        }
        decoratorsInfo.push(decoratorInfo);
    }
    return decoratorsInfo;
}
exports.extractDecoratorsFromSignature = extractDecoratorsFromSignature;
function extractDefaultValue(parameter) {
    if (!typescript_1.default.isParameter(parameter.valueDeclaration))
        return undefined;
    if (!parameter.valueDeclaration.initializer)
        return undefined;
    return parameter.valueDeclaration.initializer.getText();
}
exports.extractDefaultValue = extractDefaultValue;
function extractSignatureMeta(method) {
    const signature = TS_1.TS.typeChecker.getSignatureFromDeclaration(method);
    const result = {
        name: method.name.text,
        parameters: [],
    };
    result.parameters = signature.parameters.map(param => {
        return {
            name: param.name,
            type: TS_1.TS.typeChecker.typeToString(TS_1.TS.typeChecker.getTypeOfSymbolAtLocation(param, param.valueDeclaration)),
            defaultValue: extractDefaultValue(param),
        };
    });
    return result;
}
exports.extractSignatureMeta = extractSignatureMeta;
//# sourceMappingURL=Signature.js.map