"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createVueDtsFile = void 0;
const typescript_1 = __importDefault(require("typescript"));
const Imports_1 = require("./Imports");
const { factory } = typescript_1.default;
function createVueDtsFile(stores) {
    /**
     * This code will generate the following:
     *
     * declare module "@vue/runtime-core" {
     *   import {storeExportName} from "./StoreName";
     * 	 interface ComponentCustomProperties {
     * 		$storeVueBinding: typeof storeExportName;
     * 	 }
     * }
     *
     * export {};
     */
    /**
     * This will generate:
     * $storeVueBinding: typeof storeExportName;
     */
    const componentProperties = stores.map(store => factory.createPropertySignature(undefined, factory.createIdentifier(store.vueBinding), undefined, factory.createTypeQueryNode(factory.createIdentifier(store.exportName), undefined)));
    /**
     * This will generate our imports:
     * import {storeExportName} from "./StoreName";
     */
    const storeImports = stores.map(store => (0, Imports_1.createRelativeImportNode)([store.exportName], store.relStoreFilePath));
    /**
     * This will generate the main declare module/interface block
     */
    const declareModuleBlock = factory.createModuleDeclaration([factory.createModifier(typescript_1.default.SyntaxKind.DeclareKeyword)], factory.createStringLiteral("@vue/runtime-core"), factory.createModuleBlock([
        ...storeImports,
        factory.createInterfaceDeclaration(undefined, factory.createIdentifier("ComponentCustomProperties"), undefined, undefined, componentProperties)
    ]), typescript_1.default.NodeFlags.ExportContext /*| ts.NodeFlags.Ambient*/ | typescript_1.default.NodeFlags.ContextFlags);
    return [
        declareModuleBlock,
        factory.createExportDeclaration(undefined, false, factory.createNamedExports([]), undefined, undefined),
    ];
}
exports.createVueDtsFile = createVueDtsFile;
//# sourceMappingURL=VueDtsFile.js.map