"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ClassStoresPlugin = void 0;
const plugin_typescript_1 = __importDefault(require("@rollup/plugin-typescript"));
const path_1 = __importDefault(require("path"));
const Imports_1 = require("./Builders/Imports");
const PluginConfig_1 = require("./PluginConfig");
const Transformer_1 = __importStar(require("./Transformer"));
const ViteFunction_1 = require("./Utils/ViteFunction");
const Generator_1 = require("./Generator");
const Logger_1 = require("./Logger");
const context = new Generator_1.Context();
function ClassStoresPlugin(configuration) {
    PluginConfig_1.PluginConfig.setUserConfig(configuration);
    let server;
    const plugin = {
        name: 'class-stores-loader',
        configResolved(config) {
            PluginConfig_1.PluginConfig.init(config);
            context.init();
            context.process();
        },
        configureServer(devServer) {
            server = devServer;
            server.watcher.on('all', (eventName, filePath, stats) => {
                if (!['add', 'change', 'unlink'].includes(eventName)) {
                    return;
                }
                if (PluginConfig_1.PluginConfig.isGeneratedFile(filePath)) {
                    return;
                }
                if (!filePath.startsWith(PluginConfig_1.PluginConfig.storesPath)) {
                    return;
                }
                context.reloadModules();
                if (['change', 'unlink'].includes(eventName)) {
                    const store = context.getStoreByFilePath(filePath);
                    if (!store) {
                        return;
                    }
                    eventName === 'unlink'
                        ? (0, Logger_1.infoLog)(`Store file deletion detected: ${store.className}`)
                        : (0, Logger_1.infoLog)(`Store file change detected: ${store.className}`);
                    (0, Logger_1.infoLog)(`Rebuilding stores...`);
                    context.rebuild();
                    return;
                }
                let store = context.getStoreByFilePath(filePath);
                if (!store) {
                    (0, Logger_1.infoLog)(`New file detected: ${filePath}`);
                    (0, Logger_1.infoLog)(`Rebuilding store meta...`);
                    context.process();
                }
                // Just to ensure it was actually a new store, not a random file
                store = context.getStoreByFilePath(filePath);
                if (store) {
                    (0, Logger_1.infoLog)(`Addition was a new store: ${store.className}`);
                    (0, Logger_1.infoLog)(`Rebuilding stores...`);
                    context.rebuild();
                }
            });
        },
        transform(code, id) {
            return __awaiter(this, void 0, void 0, function* () {
                if (/node_modules\/(?!\.vite\/)/.test(id))
                    return;
                if (!id.endsWith('.ts'))
                    return;
                const ast = this.parse(code);
                const ms = new ViteFunction_1.MagicString(code);
                let transformed = false;
                yield (0, ViteFunction_1.walk)(ast, {
                    CallExpression(node) {
                        var _a, _b, _c, _d, _e, _f;
                        if (((_a = node.callee) === null || _a === void 0 ? void 0 : _a.type) !== 'MemberExpression')
                            return;
                        /**
                         * Transform app.use(StoreManager.boot()) to
                         * app.use(StoreManager.boot(import.meta.glob('./Stores/Generated/StoreLoader.ts', {eager:true})))
                         */
                        const expression = node.callee;
                        if (((_b = expression.object) === null || _b === void 0 ? void 0 : _b.type) !== 'Identifier')
                            return;
                        if (((_c = expression.object) === null || _c === void 0 ? void 0 : _c.name) !== 'StoreManager')
                            return;
                        if (((_d = expression.property) === null || _d === void 0 ? void 0 : _d.type) !== 'Identifier')
                            return;
                        if (((_e = expression.property) === null || _e === void 0 ? void 0 : _e.name) !== 'boot')
                            return;
                        if (!!((_f = node === null || node === void 0 ? void 0 : node.arguments) === null || _f === void 0 ? void 0 : _f.length))
                            return;
                        const statementCode = code.slice(node.start, node.end);
                        const loaderImportPath = PluginConfig_1.PluginConfig.getRelativeLoaderImportPath(id);
                        transformed = true;
                        const newStatement = `StoreManager.boot(import.meta.glob('${loaderImportPath}', {eager:true}))`;
                        (0, Logger_1.infoLog)(`Transformed boot call from "${statementCode}" to "${newStatement}"`);
                        ms.overwrite(node.start, node.end, newStatement);
                    }
                });
                if (transformed) {
                    const dir = path_1.default.dirname(id);
                    const storeImports = context.stores.map(store => `'${(0, Imports_1.formatImportString)(path_1.default.relative(dir, store.absFilePath))}.ts'`);
                    const loaderImport = PluginConfig_1.PluginConfig.getRelativeLoaderImportPath(id);
                    ms.append(`
				if(import.meta.hot) {
					let ___loaderModule = null;
					import.meta.hot.accept('${loaderImport}', (dep) => {
						if(dep) {
							___loaderModule = dep;
						}
                        StoreManager.loaderReloaded(___loaderModule?.stores);
					})
				}`);
                }
                const msResult = ms.toString();
                if (msResult === code)
                    return;
                return msResult;
            });
        },
        buildStart(options) {
            context.writeFiles();
        },
    };
    if ((0, Transformer_1.isTestingEnv)()) {
        return [
            plugin,
            (0, plugin_typescript_1.default)({
                transformers: {
                    before: [
                        {
                            type: 'program',
                            factory: (program) => (0, Transformer_1.default)(program),
                        },
                    ],
                },
            })
        ];
    }
    return plugin;
}
exports.ClassStoresPlugin = ClassStoresPlugin;
exports.default = ClassStoresPlugin;
//# sourceMappingURL=ClassStoresPlugin.js.map