"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.warnLog = exports.basicLog = exports.infoLog = exports.debugLog = exports.errorLog = exports.successLog = exports.colors = void 0;
exports.colors = {
    Reset: "\x1b[0m",
    Bright: "\x1b[1m",
    Dim: "\x1b[2m",
    Underscore: "\x1b[4m",
    Blink: "\x1b[5m",
    Reverse: "\x1b[7m",
    Hidden: "\x1b[8m",
    FgBlack: "\x1b[30m",
    FgRed: "\x1b[31m",
    FgGreen: "\x1b[32m",
    FgYellow: "\x1b[33m",
    FgBlue: "\x1b[34m",
    FgMagenta: "\x1b[35m",
    FgCyan: "\x1b[36m",
    FgWhite: "\x1b[37m",
    BgBlack: "\x1b[40m",
    BgRed: "\x1b[101m",
    BgGreen: "\x1b[42m",
    BgYellow: "\x1b[43m",
    BgBlue: "\x1b[44m",
    BgMagenta: "\x1b[45m",
    BgCyan: "\x1b[46m",
    BgWhite: "\x1b[47m",
    WrapBold: (text) => {
        return '\u001b[1m' + text + '\u001b[22m';
    },
    WrapUnderscore: (text) => {
        return exports.colors.Underscore + text + exports.colors.Reset;
    },
    WrapBgRed: (text) => `${exports.colors.BgRed}${text}${exports.colors.Reset}`,
    WrapBgYellow: (text) => `${exports.colors.BgYellow}${text}${exports.colors.Reset}`,
    WrapBgBlue: (text) => `${exports.colors.BgBlue}${text}${exports.colors.Reset}`,
    WrapBgForLog: (type, text) => {
        switch (type) {
            case 'error':
                return exports.colors.WrapBgRed(exports.colors.Bright + exports.colors.WrapBold(text) + exports.colors.Reset);
            case 'warning':
                return exports.colors.WrapBgYellow(exports.colors.Bright + exports.colors.WrapBold(text) + exports.colors.Reset);
            case 'info':
                return exports.colors.WrapBgBlue(exports.colors.Bright + exports.colors.WrapBold(text) + exports.colors.Reset);
        }
    },
    Wrap: (color, text) => {
        return `${color}${text}${exports.colors.Reset}`;
    },
    ResetWrap: (text) => {
        return `${exports.colors.Reset}${text}${exports.colors.Reset}`;
    }
};
function successLog(...args) {
    console.log(exports.colors.Wrap(exports.colors.FgGreen, ' ✓'), args.map(a => exports.colors.Wrap(exports.colors.Dim, a)).join(' '), exports.colors.Reset);
}
exports.successLog = successLog;
function errorLog(...args) {
    console.log(exports.colors.Wrap(exports.colors.FgRed, ' ✗'), args.map(a => exports.colors.Wrap(exports.colors.Dim, a)).join(' '), exports.colors.Reset);
}
exports.errorLog = errorLog;
function debugLog(...args) {
    if (process.env.DEBUG_MODE) {
        console.log(exports.colors.Wrap(exports.colors.Dim, ' i'), args.map(a => exports.colors.Wrap(exports.colors.Dim, a)).join(' '), exports.colors.Reset);
    }
}
exports.debugLog = debugLog;
function infoLog(...args) {
    console.log(exports.colors.Wrap(exports.colors.FgBlue, ' i'), args.map(a => exports.colors.Wrap(exports.colors.Dim, a)).join(' '), exports.colors.Reset);
}
exports.infoLog = infoLog;
function basicLog(...args) {
    console.log(args.map(a => exports.colors.Wrap(exports.colors.Dim, a)).join(' '), exports.colors.Reset);
}
exports.basicLog = basicLog;
function warnLog(...args) {
    const segments = [/*LOG_PREFIX,*/ exports.colors.Wrap(exports.colors.FgYellow, ' !')].join('');
    console.log(segments, args.map(a => exports.colors.Wrap(exports.colors.Dim, a)).join(' '));
}
exports.warnLog = warnLog;
//# sourceMappingURL=Logger.js.map