import jetpack from "fs-jetpack";
import ts from "typescript";
import { ResolvedConfig } from "vite";
export declare type UserPluginConfig = {
    projectRoot?: string;
    storesPath: string;
    storesFileName?: string;
};
declare class PluginConfigInstance {
    /**
     * The project root dir
     * @type {string}
     */
    projectRoot?: string;
    /**
     * Filesystem instance for the project root
     * @type {typeof jetpack}
     */
    projectRootDirectory: typeof jetpack;
    /**
     * The path to where our stores are located
     * @type {string}
     */
    storesPath: string;
    /**
     * Filesystem instance for the stores path
     * @type {typeof jetpack}
     */
    storesDirectory: typeof jetpack;
    /**
     * The name of the vue declaration file that will be generated
     * For ex: stores.d.ts
     * @type {string}
     */
    storesFileName?: string;
    /**
     * The name of the store loader file that will be generated
     * This contains an array of all the stores and their meta.
     * @type {string}
     */
    storeLoaderFile: string;
    /**
     * The directory name inside the stores path where
     * all generated files will be written
     * @type {string}
     */
    generatedDirName: string;
    /**
     * Filesystem instance for the generated files path
     * @type {typeof jetpack}
     */
    generatedDir: typeof jetpack;
    /**
     * The resolved vite configuration
     *
     * @type {ResolvedConfig}
     * @private
     */
    viteConfig: ResolvedConfig;
    private _tsConfigPath;
    private _parsedCommandLine;
    /**
     * The file paths to all of our store files
     *
     * @type {string[]}
     */
    storeFilePaths: string[];
    setUserConfig(config: UserPluginConfig): void;
    init(config: ResolvedConfig): void;
    get tsConfigPath(): any;
    get tsConfig(): ts.ParsedCommandLine;
    get vueDtsPath(): string;
    get storeLoaderPath(): string;
    setStoreFilePaths(): void;
    /**
     * Checks if the specified file is one that's generated by the plugin.
     * This is used within things like the HMR handler to prevent infinite loops.
     * @param {string} file
     */
    isGeneratedFile(file: string): boolean;
    getRelativeLoaderImportPath(from: string): any;
}
export declare const PluginConfig: PluginConfigInstance;
export {};
