"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ProcessingContext = exports.ProcessingContextInstance = void 0;
const ErrorMessages_1 = require("../ErrorMessages");
const Linting_1 = require("../Linting");
class ProcessingContextInstance {
    constructor() {
        Object.defineProperty(this, "linter", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        /**
         * The module that's currently being processed
         */
        Object.defineProperty(this, "module", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        /**
         * The store that we're currently processing
         */
        Object.defineProperty(this, "store", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        /**
         * The class that's currently being processed
         */
        Object.defineProperty(this, "classDeclaration", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        /**
         * The method that is currently being processed, if we're processing one.
         */
        Object.defineProperty(this, "methodDeclaration", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "action", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
    }
    setCurrent(module, store) {
        this.classDeclaration = undefined;
        this.module = module;
        this.store = store;
        this.linter = Linting_1.Linting.factory(module);
    }
    validate() {
        if (this.classDeclaration) {
            if (!this.store.exportName) {
                this.linter.error(ErrorMessages_1.errorMessages.store.missingExport(this.store.className), this.classDeclaration);
            }
            if (!this.store.stateObj) {
                this.linter.error(ErrorMessages_1.errorMessages.stateGetter.missingStateGetter(this.store.className), this.classDeclaration);
            }
        }
        this.linter.merge();
    }
    processingStoreClass(classDeclaration, handlerFunc) {
        this.classDeclaration = classDeclaration;
        handlerFunc();
        this.classDeclaration = undefined;
    }
    /**
     * We use a callback here so that we can temporarily set the method
     * on the context, and remove it again once we're done
     */
    processingAction(action, handlerFunc) {
        this.methodDeclaration = action.method;
        this.action = action;
        handlerFunc();
        this.methodDeclaration = undefined;
        this.action = undefined;
    }
}
exports.ProcessingContextInstance = ProcessingContextInstance;
exports.ProcessingContext = new ProcessingContextInstance();
//# sourceMappingURL=ProcessingContext.js.map