"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Timed = exports.endTimer = exports.startTimer = void 0;
const timings = new Map();
function startTimer(name) {
    if (!process.env.DEBUG_MODE) {
        return;
    }
    timings.set(name, Date.now());
}
exports.startTimer = startTimer;
function endTimer(name) {
    if (!process.env.DEBUG_MODE) {
        return;
    }
    const start = timings.get(name);
    if (start == null) {
        throw new Error(`Timer ${name} was never started`);
    }
    const end = Date.now();
    const duration = end - start;
    console.log(`${name} took ${duration}ms`);
    timings.delete(name);
}
exports.endTimer = endTimer;
exports.Timed = {
    start: startTimer,
    end: endTimer,
    func: (name, cb, id) => {
        startTimer(name + (id !== null && id !== void 0 ? id : ''));
        const result = cb();
        if (result instanceof Promise) {
            result.then(() => endTimer(name + (id !== null && id !== void 0 ? id : '')));
        }
        else {
            endTimer(name + (id !== null && id !== void 0 ? id : ''));
        }
    }
};
//# sourceMappingURL=Timed.js.map