"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.normalizePath = exports.walk = exports.relativeify = exports.MagicString = exports.cleanUrl = void 0;
const node_path_1 = __importDefault(require("node:path"));
const node_os_1 = __importDefault(require("node:os"));
function cleanUrl(url) {
    const queryRE = /\?.*$/s;
    const hashRE = /#.*$/s;
    return url.replace(hashRE, '').replace(queryRE, '');
}
exports.cleanUrl = cleanUrl;
/**
 * @see https://github.com/rich-harris/magic-string
 */
class MagicString {
    constructor(str) {
        Object.defineProperty(this, "str", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "starts", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "ends", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "overwrites", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        this.str = str;
        this.starts = '';
        this.ends = '';
    }
    append(content) {
        this.ends += content;
        return this;
    }
    prepend(content) {
        this.starts = content + this.starts;
        return this;
    }
    overwrite(start, end, content) {
        if (end < start) {
            throw new Error(`"end" con't be less than "start".`);
        }
        if (!this.overwrites) {
            this.overwrites = [];
        }
        this.overwrites.push({ loc: [start, end], content });
        return this;
    }
    toString() {
        let str = this.str;
        if (this.overwrites) {
            const arr = [...this.overwrites].sort((a, b) => b.loc[0] - a.loc[0]);
            for (const { loc: [start, end], content } of arr) {
                // TODO: check start or end overlap
                str = str.slice(0, start) + content + str.slice(end);
            }
        }
        return this.starts + str + this.ends;
    }
}
exports.MagicString = MagicString;
/**
 * - `'' -> '.'`
 * - `foo` -> `./foo`
 */
function relativeify(relative) {
    if (relative === '') {
        return '.';
    }
    if (!relative.startsWith('.')) {
        return './' + relative;
    }
    return relative;
}
exports.relativeify = relativeify;
/**
 * Ast tree walk
 */
function walk(ast, visitors, ancestors = []) {
    return __awaiter(this, void 0, void 0, function* () {
        var _a;
        if (!ast)
            return;
        if (Array.isArray(ast)) {
            for (const element of ast) {
                yield walk(element, visitors, ancestors);
            }
        }
        else {
            ancestors = ancestors.concat(ast);
            for (const key of Object.keys(ast)) {
                yield (typeof ast[key] === 'object' && walk(ast[key], visitors, ancestors));
            }
        }
        yield ((_a = visitors[ast.type]) === null || _a === void 0 ? void 0 : _a.call(visitors, ast, ancestors));
    });
}
exports.walk = walk;
walk.sync = function walkSync(ast, visitors, ancestors = []) {
    var _a;
    if (!ast)
        return;
    if (Array.isArray(ast)) {
        for (const element of ast) {
            walkSync(element, visitors, ancestors);
        }
    }
    else {
        ancestors = ancestors.concat(ast);
        for (const key of Object.keys(ast)) {
            typeof ast[key] === 'object' && walkSync(ast[key], visitors, ancestors);
        }
    }
    (_a = visitors[ast.type]) === null || _a === void 0 ? void 0 : _a.call(visitors, ast, ancestors);
};
const isWindows = node_os_1.default.platform() === 'win32';
function slash(p) {
    return p.replace(/\\/g, '/');
}
function normalizePath(id) {
    return node_path_1.default.posix.normalize(isWindows ? slash(id) : id);
}
exports.normalizePath = normalizePath;
//# sourceMappingURL=ViteFunction.js.map